# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/sac/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/litecms/sac/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Litecms\\Sac\\": "packages/litecms/sac/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Sac\Providers\SacServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Sac'  => Litecms\Sac\Facades\Sac::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\SacTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Sac\Providers\SacServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Sac\Providers\SacServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Sac\Providers\SacServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/sac/{modulename}

**User**

    http://path-to-route-folder/user/sac/{modulename}

**Public**

    http://path-to-route-folder/sacs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/sac/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/sac/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/sac/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/sac/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/sac/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/sac/{modulename}/{slug}
    METHOD: GET