<?php

namespace Litecms\Sac\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Sac\Models\Sac;

class SacPolicy
{

    /**
     * Determine if the given user can view the sac.
     *
     * @param UserPolicy $user
     * @param Sac $sac
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sac $sac)
    {
        if ($user->canDo('sac.sac.view') && $user->isAdmin()) {
            return true;
        }

        return $sac->user_id == user_id() && $sac->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sac.
     *
     * @param UserPolicy $user
     * @param Sac $sac
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sac.sac.create');
    }

    /**
     * Determine if the given user can update the given sac.
     *
     * @param UserPolicy $user
     * @param Sac $sac
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sac $sac)
    {
        if ($user->canDo('sac.sac.edit') && $user->isAdmin()) {
            return true;
        }

        return $sac->user_id == user_id() && $sac->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sac.
     *
     * @param UserPolicy $user
     * @param Sac $sac
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sac $sac)
    {
        return $sac->user_id == user_id() && $sac->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sac.
     *
     * @param UserPolicy $user
     * @param Sac $sac
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sac $sac)
    {
        if ($user->canDo('sac.sac.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sac.
     *
     * @param UserPolicy $user
     * @param Sac $sac
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sac $sac)
    {
        if ($user->canDo('sac.sac.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
